@@ -17,6 +17,11 @@
 #define PNG_INTERNAL
 #include "gif2png.h"
 
+/* Define png_jmpbuf() in case we are using a pre-1.0.6 version of libpng */
+#ifndef png_jmpbuf
+#  define png_jmpbuf(png_ptr) (png_ptr->jmpbuf)
+#endif
+
 struct GIFelement first={NULL};
 struct GIFelement *current;
 int delete = FALSE;
@@ -274,7 +279,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 		    colors[i].red, colors[i].blue, colors[i].green);  
 	}
 
-    if (setjmp(png_ptr->jmpbuf)) {
+    if (setjmp(png_jmpbuf(png_ptr))) {
 	fprintf(stderr, "gif2png:  libpng returns fatal error condition\n");
 	free(png_ptr);
 	free(info_ptr);
@@ -481,7 +486,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	case GIFcomment:
 	    data = access_data(s, 0, s->size);
 	    j = s->size;
-	    if (data[j-1] == '\0')  /* some apps include a NULL in GIF comment */
+	    if (j > 0 && data[j-1] == '\0')  /* some apps include a NULL in GIF comment */
 		--j;
 	    if (j<500) {
 		png_write_tEXt(png_ptr, "Comment", (png_charp)data, j);
@@ -568,14 +573,16 @@ MatteGIF(GifColor matte)
 		fprintf(stderr, 
 			"gif2png: no transparency color in image %d, matte argument ignored\n",
 			icount);
-	    else if (verbose) {
-		fprintf(stderr, 
+	    else {
+		if (verbose) {
+		    fprintf(stderr, 
 			"gif2png: transparent value in image %d is %d\n",  
 			icount, current->imagestruct->trans);
-	    }
+		}
 
-	    current->imagestruct->colors[current->imagestruct->trans] = matte;
-	    current->imagestruct->trans = -1;
+		current->imagestruct->colors[current->imagestruct->trans] = matte;
+		current->imagestruct->trans = -1;
+	    }
 	}
     }
     return icount;
